#! /bin/csh -f
#
#  Conversion script to output I+ - I- from  an mtz  in SHELX format
#              OR output IMEAN - IMEAN from two mtzs in SHELX format
#
set nawk = /bin/awk
$nawk 'BEGIN{print}' >& /dev/null
if($status) set nawk = awk
alias nawk $nawk
#
set ano_outfile = "SHELX_ano.hkl"
set iso_outfile = "SHELX_iso.hkl"
#
set tempfile = /tmp/jamesh/scaler_temp7261.mtz2shelx
#
goto Setup
#######################################
#
#   usage: ./SHELX/mtz2SHELX.com [native.mtz] derivative.mtz
#
#######################################
ReturnFromSetup:

Dano:
echo "outputting anomalous differences from $infiles in SHELX format as $ano_outfile"

# SHELX anomalous
mtz2various hklin $infiles \
            hklout ${tempfile}hkl << EOF-shelx1
OUTPUT SHELX
LABIN FP=I(-) SIGFP=SIGI(-) FPH=I(+) SIGFPH=SIGI(+)
END
EOF-shelx1
if($status) exit 3

# strip off non-SHELX lines
cat ${tempfile}hkl | nawk '$1 !~ /[A-Z]/ && $5 != 0' >! $ano_outfile

# print out mean DI/sigma
nawk '(NF == 6)&&($5 != 0){sum += $4/$5; ++n} END{if(n) print "Dano/sig =", sum/n}' $ano_outfile

goto cleanup

Diso:
# SHELX can also use isomorphous differences

echo "outputting isomorphous difference between $infiles in SHELX format as $iso_outfile"
echo "$infiles had better be on the same scale! "

# do difference HKLs
cad HKLIN1 $infiles[1]                     \
    HKLIN2 $infiles[2]                     \
    HKLOUT ${tempfile}shelx.mtz  << eof-cad-shelx
LABI FILE 1 E1=IMEAN E2=SIGIMEAN
CTYP FILE 1 E1=J     E2=Q
LABO FILE 1 E1=I1    E2=SIGI1
        
LABI FILE 2 E1=IMEAN E2=SIGIMEAN
CTYP FILE 2 E1=J     E2=Q
LABO FILE 2 E1=I2    E2=SIGI2
eof-cad-shelx
if($status) exit 2

# Dump difference in SHELX format
mtz2various hklin ${tempfile}shelx.mtz     \
            hklout ${tempfile}hkl  << EOF-shelx2
OUTPUT SHELX
LABIN FP=I2 SIGFP=SIGI2 FPH=I1 SIGFPH=SIGI1
END
EOF-shelx2
if($status) exit 3

# strip off non-SHELX lines
cat ${tempfile}hkl | nawk '$1 !~ /[A-Z]/ && $5 != 0' >! $iso_outfile

# print out mean DI/sigma
nawk '(NF == 6)&&($5 != 0){sum += $4/$5; ++n} END{if(n) print "Diso/sig =", sum/n}' $iso_outfile


cleanup:
rm -f ${tempfile}shelx.mtz >& /dev/null
rm -f ${tempfile}hkl       >& /dev/null

exit

#####################################################################

Setup:
set infiles
foreach arg ( $* )
    if(($arg =~ *.mtz)&&(-e $arg)) then
	if($arg =~ *.mtz) set infiles = `echo $arg $infiles`
    endif
end

if ($#infiles == 1) then
    # do something to identify Is?
    goto Dano
endif

if ($#infiles == 2) then
    # do something to identify Is?
    goto Diso
endif

# no files, exit
cat << EOF
usage: $0 native.mtz derivative.mtz	(output DISO in $iso_outfile)
       OR
       $0 derivative.mtz		(output DANO in $ano_outfile)
       
NOTE: NO scaling will be done.  
      Make sure your MTZs are on the same scale.

EOF
exit 9

goto ReturnFromSetup


