#! /bin/csh -f
#
#   Sorting script made by Scaler Elves
#
# Defaults
set SG       = P6122
set outfile  = "./mtz/rawdata.mtz"
set tempfile = "${CCP4_SCR}/sort_temp$$"
#
set nawk = /bin/awk
$nawk 'BEGIN{print}' >& /dev/null
if($status) set nawk = awk
alias nawk $nawk
#
goto Setup
############################
#
# usage: ./scripts/sort_everything.com [sg]
# where: [sg] is the new space group
#    eg: ./scripts/sort_everything.com P6122
#        means reindex all data to P6122 (and sort it)
#
############################
ReturnFromSetup:
#####################################################
# add 11000 to 1 through 100 in ../raw.mtz
rebatch HKLIN ../raw.mtz HKLOUT ${tempfile}run1.mtz << EOF-rebatch
BATCH 1 TO 100 INCLUDE 
BATCH 1 TO 100 ADD 11000
#BATCH 1 TO 100 pname data xname xtal dname FP
EOF-rebatch

#####################################################

# sort all runs together into one, big MTZ
sortmtz HKLOUT $outfile << EOF-sort
#VRSET -9E+38
H K L M/ISYM BATCH I SIGI
${tempfile}run1.mtz
EOF-sort
if(! $status) then
    echo "data from all runs and all wavelengths are now in: $outfile"
else
    echo "sorting failed!  Check for overlapping batch numbers."
    set BAD
    exit 9
endif

# now check to see if we need to reindex
set sg = `echo "HEAD" | mtzdump hklin $outfile | nawk '/Space group =/{print $5}'`
if(("$sg" != "$SG")&&(! $?REINDEX)) then
    set REINDEX = ""
endif

#####################################################

# clean up
rm -f ${tempfile}run1.mtz
if($?REINDEX) goto reindex
exit
#####################################################
reindex:


# re-index all data to new space group
reindex HKLIN $outfile HKLOUT ${tempfile}reindex.mtz << EOF-reindex
SYMM $SG
$REINDEX
EOF-reindex
if($status) set BAD

# sort again
sortmtz HKLOUT $outfile << EOF-sort
#VRSET -9E+38
H K L M/ISYM BATCH I SIGI
${tempfile}reindex.mtz
EOF-sort
if($status) set BAD

if(! $?BAD) then
    echo "$outfile is now in $SG"
else
    echo "reindexing failed, Dang."
    exit 9
endif

rm -f ${tempfile}reindex.mtz

exit
#####################################################
Setup:
foreach arg ( $* )
    # new space group? 
    if("$arg" =~ [PpCcIiFfRrHh][1-6]*) then
	set temp = `nawk -v SG=$arg '$4 == toupper(SG) && $1 < 500 {print $4}' $CLIBD/symop.lib | head -1`
	if("$temp" =~ [PpCcIiFfRrHh][1-6]*) then
	    set SG = "$temp"
	else
	    # check for "pseudo-spacegroup" language
	    if("$arg" =~ [Pp]2212) then
		# P2221 with screw along current "b"
		set SG = "P2221"
		set REINDEX = "reindex l, h, k"
	    endif
	    if("$arg" =~ [Pp]2122) then
		# P2221 with screw along current "a"
		set SG = "P2221"
		set REINDEX = "reindex k, l, h"
	    endif
	    if("$arg" =~ [Pp]21221) then
		# P21212 with non-screw along current "b"
		set SG = "P21212"
		set REINDEX = "reindex l, h, k"
	    endif
	    if("$arg" =~ [Pp]22121) then
		# P21212 with non-screw along current "a"
		set SG = "P21212"
		set REINDEX = "reindex k, l, h"
	    endif
	    if("$arg" =~ [Cc]2212) then
		# C2221 with screw along current "b"
		set SG = "C2221"
		set REINDEX = "reindex l, h, k"
	    endif
	    if("$arg" =~ [Cc]2122) then
		# C2221 with screw along current "a"
		set SG = "C2221"
		set REINDEX = "reindex k, l, h"
	    endif
	endif
    endif
end
goto ReturnFromSetup

